// Package all registers all builtin formats with the default registry
//nolint:revive
package all

import (
	_ "github.com/wader/fq/format/ape"
	_ "github.com/wader/fq/format/ar"
	_ "github.com/wader/fq/format/av1"
	_ "github.com/wader/fq/format/bencode"
	_ "github.com/wader/fq/format/bson"
	_ "github.com/wader/fq/format/bzip2"
	_ "github.com/wader/fq/format/cbor"
	_ "github.com/wader/fq/format/dns"
	_ "github.com/wader/fq/format/elf"
	_ "github.com/wader/fq/format/flac"
	_ "github.com/wader/fq/format/gif"
	_ "github.com/wader/fq/format/gzip"
	_ "github.com/wader/fq/format/icc"
	_ "github.com/wader/fq/format/id3"
	_ "github.com/wader/fq/format/inet"
	_ "github.com/wader/fq/format/jpeg"
	_ "github.com/wader/fq/format/json"
	_ "github.com/wader/fq/format/matroska"
	_ "github.com/wader/fq/format/mp3"
	_ "github.com/wader/fq/format/mp4"
	_ "github.com/wader/fq/format/mpeg"
	_ "github.com/wader/fq/format/msgpack"
	_ "github.com/wader/fq/format/ogg"
	_ "github.com/wader/fq/format/opus"
	_ "github.com/wader/fq/format/pcap"
	_ "github.com/wader/fq/format/png"
	_ "github.com/wader/fq/format/protobuf"
	_ "github.com/wader/fq/format/raw"
	_ "github.com/wader/fq/format/tar"
	_ "github.com/wader/fq/format/tiff"
	_ "github.com/wader/fq/format/vorbis"
	_ "github.com/wader/fq/format/vpx"
	_ "github.com/wader/fq/format/wav"
	_ "github.com/wader/fq/format/webp"
	_ "github.com/wader/fq/format/zip"
)
